// @ts-nocheck
import hapi from '@hapi/hapi';
import nes from '@hapi/nes';

import { host, port } from 'config/server.json';
import { dbConnect } from 'database/db';

import swagger from 'plugins/swagger';

const server: hapi.Server = new hapi.Server({
	host: host,
	port: port,
	debug: {
		log: ['error'],
		request: ['error'],
	},
	routes: {
		validate: {
			failAction: (request, h, err) => {
				throw err;
			},
		},
	},
});

const start = async (): Promise<void> => {
	await swagger(server);
	await server.register(nes);

	// v1 endpoints
	await server.register(require('./plugins/controllers'), { routes: { prefix: '/api/v1' } });

	// connect to database
	await dbConnect()
		.then(() => {
			console.log('Data Source has been initialized!');
		})
		.catch((err) => {
			console.error('Error during Data Source initialization', err);
		});

	await server.start();
	console.info(`Server running: ${server.info.uri}`);
};

process.on('unhandledRejection', (err) => {
	console.info(err);
	process.exit(1);
});

start();
